You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@shale.apache.org by ra...@apache.org on 2006/09/13 00:55:58 UTC

svn commit: r442748 - /shale/sandbox/shale-test-dialog2-scxml/src/test/java/org/apache/shale/examples/test/dialog2/scxml/systest/IntegrationTestCase.java

Author: rahul
Date: Tue Sep 12 15:55:58 2006
New Revision: 442748

URL: http://svn.apache.org/viewvc?view=rev&rev=442748
Log:
I haven't ever run these m2 integration tests, i.e. to say, these may not pass ;-) I may be running out of time today, but these seem like a couple of obvious fixes.

Modified:
    shale/sandbox/shale-test-dialog2-scxml/src/test/java/org/apache/shale/examples/test/dialog2/scxml/systest/IntegrationTestCase.java

Modified: shale/sandbox/shale-test-dialog2-scxml/src/test/java/org/apache/shale/examples/test/dialog2/scxml/systest/IntegrationTestCase.java
URL: http://svn.apache.org/viewvc/shale/sandbox/shale-test-dialog2-scxml/src/test/java/org/apache/shale/examples/test/dialog2/scxml/systest/IntegrationTestCase.java?view=diff&rev=442748&r1=442747&r2=442748
==============================================================================
--- shale/sandbox/shale-test-dialog2-scxml/src/test/java/org/apache/shale/examples/test/dialog2/scxml/systest/IntegrationTestCase.java (original)
+++ shale/sandbox/shale-test-dialog2-scxml/src/test/java/org/apache/shale/examples/test/dialog2/scxml/systest/IntegrationTestCase.java Tue Sep 12 15:55:58 2006
@@ -26,7 +26,7 @@
 import com.gargoylesoftware.htmlunit.html.HtmlSubmitInput;
 
 /**
  * <p>Integration tests for the Shale Dialog2 Legacy Implementation.</p>
  */
 public class IntegrationTestCase extends AbstractHtmlUnitTestCase {
     
@@ -87,7 +87,7 @@
     // Test /menu.jsp
     public void testMenu() throws Exception {
 
-        assertEquals("Shale Test App (Dialog2 Legacy Implementation)", title());
+        assertEquals("Shale Test App (Dialog2 SCXML Implementation)", title());
 
     }
@@ -26,7 +26,7 @@
 
 /**
- * <p>Integration tests for the Shale Dialog2 Legacy Implementation.</p>
+ * <p>Integration tests for the Shale Dialog2 SCXML Implementation.</p>
  */
 public class IntegrationTestCase extends AbstractHtmlUnitTestCase {